@@ -2,7 +2,7 @@ import asyncio
 import ctypes
 import ctypes.wintypes
 from enum import IntFlag
-from typing import Coroutine, List
+from typing import Callable, Union
 
 import janus
 
@@ -33,7 +33,11 @@ class Hotkey:
     """
 
     def __init__(
-        self, keycode: Keycode, callback: Coroutine, *, modifiers: ModifierKeys = 0
+        self,
+        keycode: Keycode,
+        callback: Callable,
+        *,
+        modifiers: Union[ModifierKeys, int] = 0,
     ):
         self.keycode = keycode
         self.modifiers = modifiers
@@ -57,22 +61,17 @@ class Listener:
                     print("a was pressed")
 
                 hotkey = Hotkey(Keycode.A, callback)
-                listener = Listener([hotkey])
+                listener = Listener(hotkey)
 
                 # listens for a to be pressed once
                 await listener.listen()
 
     """
 
-    def __init__(
-        self, hotkeys: List[Hotkey], *, loop: asyncio.AbstractEventLoop = None
-    ):
+    def __init__(self, *hotkeys: Hotkey):
         self.ready = False
 
-        if loop is None:
-            loop = asyncio.get_event_loop()
-
-        self._loop = loop
+        self._loop = asyncio.get_event_loop()
         self._hotkeys = hotkeys
         self._callbacks = {}
         self._queue = None
@@ -101,10 +100,6 @@ class Listener:
         keycode, modifiers = message.split("|")
         keycode = int(keycode)
         modifiers = int(modifiers)
-        if modifiers == 0:
-            modifiers = 0
-        else:
-            modifiers = ModifierKeys(modifiers)
 
         # TODO: add to self._tasks and cancel in self.close
         self._loop.create_task(self._callbacks[keycode + modifiers]())
@@ -129,16 +124,16 @@ class Listener:
 
     def _add_hotkeys(self):
         for hotkey in self._hotkeys:
-            if self._register_hotkey(hotkey.keycode.value, hotkey.modifiers):
-                self._callbacks[
-                    hotkey.keycode.value + hotkey.modifiers
-                ] = hotkey.callback
+            if self._register_hotkey(hotkey.keycode.value, hotkey.modifiers.value):
+                # No repeat is not included in the return message
+                no_norepeat = hotkey.modifiers & ~ModifierKeys.NOREPEAT
+                self._callbacks[hotkey.keycode.value + no_norepeat] = hotkey.callback
             else:
                 raise HotkeyAlreadyRegistered(
                     f"{hotkey.keycode} with modifers {hotkey.modifiers}"
                 )
 
-    def _register_hotkey(self, keycode: int, modifiers: ModifierKeys = 0) -> bool:
+    def _register_hotkey(self, keycode: int, modifiers: int = 0) -> bool:
         res = user32.RegisterHotKey(None, self._id_counter, modifiers, keycode)
         self._id_counter += 1
 
