@@ -61,7 +61,9 @@ class HookHandler(MemoryReader):
         return addr
 
     async def _get_autobot_address(self):
-        addr = await self.pattern_scan(self.AUTOBOT_PATTERN)
+        addr = await self.pattern_scan(
+            self.AUTOBOT_PATTERN, module="WizardGraphicalClient.exe"
+        )
         if addr is None:
             raise RuntimeError("Pattern scan failed for autobot pattern")
 
@@ -185,7 +187,8 @@ class HookHandler(MemoryReader):
         await self.activate_player_hook(wait_for_ready=False)
         # duel is only written to on battle join
         await self.activate_duel_hook()
-        await self.activate_quest_hook(wait_for_ready=False)
+        # quest hook is not written if the quest arrow is off
+        await self.activate_quest_hook()
         await self.activate_player_stat_hook(wait_for_ready=False)
         await self.activate_client_hook(wait_for_ready=False)
         await self.activate_root_window_hook(wait_for_ready=False)
@@ -196,7 +199,6 @@ class HookHandler(MemoryReader):
             for atter_name in [
                 "player_struct",
                 "player_stat_struct",
-                "quest_struct",
                 "current_client",
                 "current_root_window",
                 "current_render_context",
@@ -239,7 +241,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(PlayerHook):
             raise HookNotActive("Player")
 
-        hook = await self._get_hook_by_type(PlayerHook)
+        hook = self._get_hook_by_type(PlayerHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -285,7 +287,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(DuelHook):
             raise HookNotActive("Duel")
 
-        hook = await self._get_hook_by_type(DuelHook)
+        hook = self._get_hook_by_type(DuelHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -301,7 +303,7 @@ class HookHandler(MemoryReader):
         return await self._read_hook_base_addr("current_duel", "Duel")
 
     async def activate_quest_hook(
-        self, *, wait_for_ready: bool = True, timeout: float = None
+        self, *, wait_for_ready: bool = False, timeout: float = None
     ):
         """
         Activate quest hook
@@ -331,7 +333,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(QuestHook):
             raise HookNotActive("Quest")
 
-        hook = await self._get_hook_by_type(QuestHook)
+        hook = self._get_hook_by_type(QuestHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -377,7 +379,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(PlayerStatHook):
             raise HookNotActive("Player stat")
 
-        hook = await self._get_hook_by_type(PlayerStatHook)
+        hook = self._get_hook_by_type(PlayerStatHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -423,7 +425,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(ClientHook):
             raise HookNotActive("Client")
 
-        hook = await self._get_hook_by_type(ClientHook)
+        hook = self._get_hook_by_type(ClientHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -473,7 +475,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(RootWindowHook):
             raise HookNotActive("Root window")
 
-        hook = await self._get_hook_by_type(RootWindowHook)
+        hook = self._get_hook_by_type(RootWindowHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -523,7 +525,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(RenderContextHook):
             raise HookNotActive("Render context")
 
-        hook = await self._get_hook_by_type(RenderContextHook)
+        hook = self._get_hook_by_type(RenderContextHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
@@ -565,7 +567,7 @@ class HookHandler(MemoryReader):
         if not self._check_if_hook_active(MouselessCursorMoveHook):
             raise HookNotActive("Mouseless cursor")
 
-        hook = await self._get_hook_by_type(MouselessCursorMoveHook)
+        hook = self._get_hook_by_type(MouselessCursorMoveHook)
         self._active_hooks.remove(hook)
         await hook.unhook()
 
