@@ -9,6 +9,9 @@ from .handler import HookHandler
 from .memory_reader import MemoryReader
 
 
+MAX_STRING = 5_000
+
+
 class MemoryObject(MemoryReader):
     """
     Class for any represented classes from memory
@@ -73,7 +76,8 @@ class MemoryObject(MemoryReader):
 
     async def read_string(self, address: int, encoding: str = "utf-8") -> str:
         string_len = await self.read_typed(address + 16, "int")
-        if string_len == 0:
+
+        if not 1 <= string_len <= MAX_STRING:
             return ""
 
         # strings larger than 16 bytes are pointers
@@ -174,7 +178,11 @@ class MemoryObject(MemoryReader):
         end_address = await self.read_value_from_offset(offset + 8, "long long")
         size = end_address - start_address
 
-        shared_pointers_data = await self.read_bytes(start_address, size)
+        try:
+            shared_pointers_data = await self.read_bytes(start_address, size)
+        except ValueError:
+            return []
+
         pointers = []
         data_pos = 0
         # Shared pointers are 16 in length
