@@ -69,7 +69,7 @@ class MemoryReader:
 
         found = []
 
-        for match in re.finditer(pattern, page_bytes):
+        for match in re.finditer(pattern, page_bytes, re.DOTALL):
             found_address = address + match.span()[0]
             found.append(found_address)
 
@@ -181,7 +181,11 @@ class MemoryReader:
         Raises:
             ClientClosedError: If the client is closed
             MemoryReadError: If there was an error reading memory
+            ValueError: If the addrress is out of bounds
         """
+        if not 0 < address <= 0x7FFFFFFFFFFFFFFF:
+            raise ValueError(f"Address {address} out of bounds")
+
         try:
             return await self.run_in_executor(self.process.read_bytes, address, size)
         except pymem.exception.MemoryReadError:
